# -*- coding: utf-8 -*-

__title__ = 'djangorestframework-apicontrol'
__version__ = '0.3.1'
__author__ = 'Marcelo Cueto'
__license__ = 'GPLv3'
__copyright__ = 'Copyright 2017-2018 Marcelo Cueto'

# Version synonym
VERSION = __version__
